Changelog
=========

0.2.1 (December 19, 2014)
-------------------------
* Added version string to puz module for version detection.

0.2 (December 19, 2014)
-----------------------

* Added support for Python 3.2+.
* Fixed issue where tests were not added properly to TestSuite.

0.1 (February 16, 2014)
-----------------------

* Initial release.
